@@ -1,11 +1,12 @@
-__version__ = "2.4.8"
+__version__ = "2.5.0"
 
 from .impl import start_connection
-from .types import AddrInfoType
+from .types import AddrInfoType, SocketFactoryType
 from .utils import addr_to_addr_infos, pop_addr_infos_interleave, remove_addr_infos
 
 __all__ = (
     "AddrInfoType",
+    "SocketFactoryType",
     "addr_to_addr_infos",
     "pop_addr_infos_interleave",
     "remove_addr_infos",
